*------------------------------------------------------------------------------*
*  Title:		Master do file                               
*
*  Date:		20/02/2025
*   													   
*  Project:		Local Infrastructure and the Development of the Private Sector: Evidence from a Randomized Trial  
*  Country:		Mexico 	
*
*  Authors:		Luis Sanchez Bayardo and Daniel Rogger							 		 
*------------------------------------------------------------------------------*


* This project uses microdata from INEGI's economic census. It is run through 
* its microdata lab, either at its premises or with the assistance of a member
* of its staff. The do files are designed to run through the workstation we use
* at INEGI.


********************************************************************************
* 			 PART 0: INSTALL PACKAGES AND STANDARDIZE SETTINGS
*
*            -Install packages needed to run all dofiles called by this master dofile
*
********************************************************************************


* Since all analysis is run at the microdata lab, through a workstation without
* access to internet, we downloaded all packages required for the analysis and
* stored them in a folder called "custom commands". This folder is then called
* in Stata.

	
********************************************************************************
* 			  PART 1: PREPARING VIRTUAL DESKTOP
*
*           -Set the global to point to the project folder 
*            on each collaborators computer.
*           -Set other locals that point to other folders of interest.
*
********************************************************************************

*Sets globals required for analysis
do "Prep 00 Declare globals.do"

	
*******************************************************************************
* 			  PART 2: IMPORT RAW DATA
*
*                  Stata (*.dta) files are from INEGI's microdata lab. 
*                  CSV (*.csv) files are from INEGI's population census public data stored in own workstation.
*
* 			  PART 3A: CLEAN UPPER AND LOWER TAILS, TRANSFORM VARIABLES TO REAL TERMS AND TO USD
* 			  PART 3B: CONSTRUCT VARIABLES
*
*  Input:         1) Insumo2009.dta 
*                 2) Insumo2014.dta
* 				  3) Insumo2019.dta
* 				  4) resultados_ageb_urbana_02_cpv2010.csv
* 				  5) resultados_ageb_urbana_04_cpv2010.csv
* 				  6) resultados_ageb_urbana_05_cpv2010.csv
* 				  7) resultados_ageb_urbana_07_cpv2010.csv
* 				  8) resultados_ageb_urbana_08_cpv2010.csv
* 				  9) resultados_ageb_urbana_09_cpv2010.csv
* 				  10) resultados_ageb_urbana_11_cpv2010.csv
* 				  11) resultados_ageb_urbana_12_cpv2010.csv
* 				  12) resultados_ageb_urbana_14_cpv2010.csv
* 				  13) resultados_ageb_urbana_15_cpv2010.csv
* 				  14) resultados_ageb_urbana_16_cpv2010.csv
* 				  15) resultados_ageb_urbana_17_cpv2010.csv
* 				  16) resultados_ageb_urbana_19_cpv2010.csv
* 				  17) resultados_ageb_urbana_21_cpv2010.csv
* 				  18) resultados_ageb_urbana_23_cpv2010.csv
* 				  19) resultados_ageb_urbana_25_cpv2010.csv
* 				  20) resultados_ageb_urbana_26_cpv2010.csv
* 				  21) resultados_ageb_urbana_28_cpv2010.csv
* 				  22) resultados_ageb_urbana_30_cpv2010.csv
* 				  23) resultados_ageb_urbana_31_cpv2010.csv

* 				  24) conjunto_de_datos_ageb_urbana_02_cpv2020.csv
* 				  25) conjunto_de_datos_ageb_urbana_04_cpv2020.csv
* 				  26) conjunto_de_datos_ageb_urbana_05_cpv2020.csv
* 				  27) conjunto_de_datos_ageb_urbana_07_cpv2020.csv
* 				  28) conjunto_de_datos_ageb_urbana_08_cpv2020.csv
* 				  29) conjunto_de_datos_ageb_urbana_09_cpv2020.csv
* 				  30) conjunto_de_datos_ageb_urbana_11_cpv2020.csv
* 				  31) conjunto_de_datos_ageb_urbana_12_cpv2020.csv
* 				  32) conjunto_de_datos_ageb_urbana_14_cpv2020.csv
* 				  33) conjunto_de_datos_ageb_urbana_15_cpv2020.csv
* 				  34) conjunto_de_datos_ageb_urbana_16_cpv2020.csv
* 				  35) conjunto_de_datos_ageb_urbana_17_cpv2020.csv
* 				  36) conjunto_de_datos_ageb_urbana_19_cpv2020.csv
* 				  37) conjunto_de_datos_ageb_urbana_21_cpv2020.csv
* 				  38) conjunto_de_datos_ageb_urbana_23_cpv2020.csv
* 				  39) conjunto_de_datos_ageb_urbana_25_cpv2020.csv
* 				  40) conjunto_de_datos_ageb_urbana_26_cpv2020.csv
* 				  41) conjunto_de_datos_ageb_urbana_28_cpv2020.csv
* 				  42) conjunto_de_datos_ageb_urbana_30_cpv2020.csv
* 				  43) conjunto_de_datos_ageb_urbana_31_cpv2020.csv
*
*  Output: 		  1) DB_Firms_all.dta
*       		  2) CensosPob_polygonW99.dta
********************************************************************************

*Imports INEGI firm census data and converts to usable database
do "Prep 01 Main database.do"

*Imports INEGI population census data and converts to usable database
do "Prep 02 Population census data.do"


	
*******************************************************************************
* 			  PART 6: CORE PAPER ANALYSIS
*
*  Input:       1) DB_Firms_all.dta
*               2) CensosPob_polygonW99.dta
*
*  Output: 		1) T1 desc stats.csv
*				2) T2 Main regs.xls
*				3) T3 ExitEntry regs.txt
*				4) T4 Survivors regs.txt
*				5) T5 Main heterogeneity regs.xls
*				6) T6 Access finance and tech regs.xls
*				7) T7 Formality Regs.xls
*				8) T8 Residents Regs.xls
*				9) T9 Spillover Regs.xls
*				10) T10 Saturation Regs.xls
********************************************************************************

*Estimate descriptive stats
do "Table 1 Descriptives.do"

*Main results
do "Table 2 Main regressions.do"
do "Table 3 Exit Entry regressions.do"
do "Table 4 Surviving firms regressions.do"

*Results by initial firm size and initial productivity (VA/L)
do "Table 5 Main heterogeneity regressions.do"

*Possible mechanisms of Habitat on firms
do "Table 6 Mechanism regressions.do"

*Effect of Habitat on formality of firms
do "Table 7 Formality regressions.do"

*Additional results on population
do "Table 8 CensusPop regs.do"

*Spillover effects
do "Table 9 Spillovers.do"

*Assesment of program saturation on main results
do "Table 10 Saturation.do"

	
*******************************************************************************
* 			  PART 7: FIGURES
*
*  Input:       1) DB_Firms_all.dta
*
*  Output: 		1) F1 Control firm dynamics.xlsx
*				2) F2 Densities.xlsx
*				3) F2 Histogram.xlsx

********************************************************************************

*Estimate Figure 1 (Firm dynamics)
do "Figure 1 Firm dynamics.do"

*Estimate Figure 2 (kernel densities and histogram)
do "Figure 2 Densities.do"


*******************************************************************************
* 			  PART 8:APPENDIX TABLES
*
*  Input:       1) DB_Firms_all.dta
*               2) IntersectControl2013.csv
*               3) IntersectControl2014.csv
*               4) IntersectControl2015.csv
*               5) IntersectControl2016.csv
*               6) IntersectControl2017.csv
*               7) IntersectTreated2013.csv
*               8) IntersectTreated2014.csv
*               9) IntersectTreated2015.csv
*               10) IntersectTreated2016.csv
*               11) IntersectTreated2017.csv
*
*  Output: 		1) TA2 Balance Post.xls
*				2) TA3 Balance Tables All sectors.xls
*				3) TA3 Balance Tables Manufacturing.xls
*				4) TA3 Balance Tables Commerce and Services.xls
*				5) TA4 ExitEntry regs.xls
*				6) TA5 Exit heterogeneity.xls
*				7) TA6 Entrants.xls
*				8) TA7 Bank access by ownwership.xls
*				9) TA8 Spillovers ExitEntry.xls
*				9) TA9 EntryExit MktAccess.xls
*				10) TA10 Main MktAccess.xlsx
*				11) TA11 Spillovers ExitEntry MktAccess.xls
*				12) TA12 Spillovers MktAccess.xls
*				13) TA13 Saturation baseline.xls
*				14) TA14 Polygon regs.xls

********************************************************************************

*Balance of Subsequent Habitat Treatment in Original Polygons
do "Table A2 Balance Posttreatment.do"

*Balance table at baseline
do "Table A3 Balance initial values.do"

*Exit and entry of firms between 2013 adn 2018
do "Table A4 Exit Entry regressions.do"

*Exit results, heterogeneity
do "Table A5 Exit heterogeneity.do"

*Entrants and correlation with Habitat
do "Table A6 Entrants.do"

*Effect of habitat on access to finance, by ownership of real estate
do "Table A7 Banking access by ownership.do"

*Spillover effects on exit and entry of firms
do "Table A8 Spillovers Exit Entry.do"

*Exit/Entry results, interacted by Market Acess measures
do "Table A9 ExitEntry regs by market access.do"

*Main results, interacted by Market Acess measures
do "Table A10 Main regs by market access.do"

*Spillover effects on exit and entry of firms, heterogeneity by market access measures
do "Table A11 Spillovers Exit Entry MarketAccess.do"

*Spillover effects, heterogeneity by market access measures
do "Table A12 Spillovers MarketAccess.do"

*Saturation of Habitat at baseline
do "Table A13 Saturation baseline.do"

*Results at polygon level
do "Table A14 Polygon results.do"
