************************************************************************************
*The World Bank
*Impact of Habitat project on firms

*Do file description: Initial data selection, treatment and creation of main database
*Author: Luis F. Sánchez-Bayardo

*This do file opens the Economic censuses of 2008 and 2013, selects the desired variables for the analysis,
*cleans them and merges both datasets into a large panel.

*Here also the manzanas to be analyzed are selected (this is customizable, according to the analysis to be made).
************************************************************************************


**** Census variables used in this Do-File ****

*+++++++++++++++++++++++++++++++++++++++++++++++++++++++*
*	Var2008	Var2013	Description							*
*+++++++++++++++++++++++++++++++++++++++++++++++++++++++*
*	id_uelm	id_uelm	Firm ID								*
*	e03		e03		State								*
*	e04		e04		Municipality						*
*	e05		e05		Locality							*
*	e06		e06		AGEB								*
*	e07		e07		Manzana								*
*	e17		e17		NAICS 6-digit sector				*
*	h000a	h000a	Workers: dependent					*
*	h001a	h001a	Workers: total						*
*	h010a	h010a	Workers: paid						*
*	h101a	h101a	Workers: blue collar				*
*	h200a	h203a	Workers: white collar				*
*	j000a	j000a	Wage bill + benefits				*
*	j100a	j010a	Wage bill: blue collar				*
*	j200a	j203a	Wage bill: white collar				*
*	k100a	k010a	Materials: for resale				*
*	k200a	k020a	Materials: for services				*
*	k300	k030a	Materials: for production			*
*	k411a	k040a	Gas, fuel and oil					*
*	k412a	k041a	Electricity							*
*	m000a	m000a	Overall revenue						*
*	m100a	m010a	Revenue: resaled goods				*
*	m200a	m020a	Revenue: services					*
*	m300a	m030a	Revenue - goods produced by firm	*
*	q000a	q000a	Capital stock: total				*
*	q101a	q010a	Capital stock: machinery			*
*	q400a	q400a	Capital stock: computer equipment	*
*	a221a	a221a	Capital formation: total			*
*+++++++++++++++++++++++++++++++++++++++++++++++++++++++*

**Global to localidades file
global routeLocs "${maindir}\Localidades in Habitat.dta"
global routeLocs19 "${maindir}\Localidades in Habitat19.dta"

**Global to call manzana files
global routeMzas09 "${maindir}\Manzanas habitat 2009(NEW).dta"
global routeMzas14 "${maindir}\Manzanas habitat 2014(NEW).dta"
global routeMzas19 "${maindir}\Manzanas habitat 2019(NEW).dta"

**Set results dir as main dir
cd "${maindir}"

**Globals containing original variables
global vars2009 "g111 h001a h000a h010a h101a h200a j000a j100a j200a m000a m100a m200a m300a q000a q400a q101a q020a a221a k100a k200a k300 k411a k412a k500a"
global vars2014 "g111 h001a h000a h010a h101a h203a j000a j010a j203a m000a m010a m020a m030a q000a q400a q010a q020a a221a k010a k020a k030a k040a k041a k050a k520a"
global vars2019 "g111a h001a h000a h010a h101a h203a j000a j010a j203a m000a m010a m020a m030a q000a q400a q010a q020a a221a k010a k020a k030a k040a k412a k050a"


*********************************************************************
**Step 1: Open 2019 Census
*********************************************************************

*Open file
use id_uelm e03 e04 e05 e06 e07 e17 using using "${insumosdir}\${file19}", clear
duplicates drop id_uelm, force
drop if substr(e17,1,1)=="1" | substr(e17,1,1)=="2"

*Create variables to identify manzanas and AGEBs
gen cve_ageb= e03+ e04+ e05+ e06
gen cve_agebmza= e03+ e04+ e05+ e06 + e07

**Doublecheck ids are properly coded
gen id=length(cve_ageb)
tab id
gen id2=length(cve_agebmza)
tab id2
replace e07="000" if e07==""
replace e07="00"+e07 if id2==14
replace e07="0"+e07 if id2==15

**Correct if id incomplete
replace cve_agebmza= e03+ e04+ e05+ e06 + e07

**Check for errors
assert length(cve_agebmza)==16

**Drop provisional vars
capture drop id id2

**Create a localidad clave, we will keep only localidades where the Habitat program was implemented
gen cve_localidad19=substr(cve_agebmza,1,9)

**Merge with file including localities
merge m:1 cve_localidad19 using "${routeLocs19}", keep(match) nogenerate
capture drop localidad_nobs
rename cve_localidad19 cve_localidad

**Merge with 2019 manzanas existing in Habitat
sort cve_agebmza
merge cve_agebmza using "${routeMzas19}"
tab _merge
drop if _merge==2
drop _merge

*Making compatible "new" NAICS sectors (i.e., exists in 2018, but not in 2013) to "old" version (in 2013) to make compatible
replace e17="311812" if e17=="311813"
replace e17="468419" if e17=="468414"
replace e17="485111" if e17=="485115"
replace e17="512210" if e17=="512250"
replace e17="517110" if e17=="517311"
replace e17="517210" if e17=="517312"
replace e17="532220" if e17=="532281"
replace e17="532291" if e17=="532282"
replace e17="532299" if e17=="532289"
replace e17="931510" if e17=="562112"
replace e17="562112" if e17=="562121"
replace e17="931510" if e17=="562122"
replace e17="562111" if e17=="562211"
replace e17="931510" if e17=="562212"
replace e17="562112" if e17=="562221"
replace e17="931510" if e17=="562222"
replace e17="562111" if e17=="562911"
replace e17="931510" if e17=="562912"
replace e17="562111" if e17=="562921"
replace e17="931510" if e17=="562922"
replace e17="562111" if e17=="562998"
replace e17="931510" if e17=="562999"
replace e17="811121" if e17=="811123"

***Rename vars
rename	g111	edad
rename	h001a	personal_ocup
rename	h000a	personal_dep
rename	h010a	personal_remun
rename	h101a	personal_blue
rename	h203a	personal_white
rename 	j000a	salarios_tot
rename	j010a	salarios_blue
rename	j203a	salarios_white
rename	m000a	ingresos_ByS
rename	m010a	ingresos_reventa
rename	m020a	ingresos_servicios
rename	m030a	Venta_productos
rename	q000a	activos_fijos
rename	q400a	equipo_computo
rename	q010a	stock_maquinaria
rename	q020a	terr_edif
rename	a221a	form_K
rename	k010a	MatPrima_reventa
rename	k020a	MatPrima_servicios
rename	k030a	MatPrima_produccion 
rename	k040a	combustibles
rename	k412a	electricidad
rename 	k050a	renta_muebEinmue
capture rename	k520a	renta_inmuebles
	
*Create sector (manufacturing, commerce, services)	IDs according to NAICS 2 digit level
gen scian=substr(e17,1,2)
destring scian, replace

gen sector=., after(e17)
replace sector=1 if scian>=31 & scian<=33	//Manufacturing
replace sector=2 if scian>=43 & scian<=46	//Commerce
replace sector=3 if scian>46 & scian!=.		//Services
drop scian

capture destring edad, replace
replace edad=. if edad<1900
replace edad=2018-edad+1

**Set varlist of variables to be cleaned (strategy: manzanas located are cleaned,
*** by group: if they belong to treatment, control or are outside of polygons.
** Variables are winsorized at 1% level at the upper tail, and at the lower tail if variables are not nonnegative.

ds
local a=r(varlist)
local b id_uelm edad e03 e04 e05 e06 e07 e17 cve_agebmza cve_localidad IDH_polygon RCT_status sector //Control Treat Other
local c:list a-b

**Winsorize control, treatment and not in Habitat groups separately
replace RCT_status=2 if RCT_status==.
foreach var of local c {
	forv x=0/2 {
		gen `var'_WV`x'=`var' if RCT_status==`x'
		sum `var'_WV`x', detail
		replace `var'_WV`x'=r(p99) if `var'_WV`x'>r(p99) & `var'_WV`x'!=.
		if r(min)<0 {
			replace `var'_WV`x'=r(p1) if `var'_WV`x'<r(p1) & `var'_WV`x'!=.
		}
	}
	gen `var'_W=.
	replace `var'_W=`var'_WV0 if RCT_status==0
	replace `var'_W=`var'_WV1 if RCT_status==1
	replace `var'_W=`var'_WV2 if RCT_status==2
	drop `var'_WV0 `var'_WV1 `var'_WV2
	sum `var' `var'_W
}
replace RCT_status=. if RCT_status==2

****************** Applying price indexes to values measure in money **********
	**By 6dig sector and variable	(most disaggregated price indexes, takes into account sector(6dig) and variables)

	*Strategy: Apply price indexes to variables starting from the most aggregate
		* Winsorized and Raw variables are kept. 
*******************************************************************************


local varsz "salarios_tot salarios_blue salarios_white MatPrima_reventa MatPrima_servicios MatPrima_produccion combustibles electricidad renta_muebEinmue renta_inmuebles ingresos_ByS ingresos_reventa ingresos_servicios Venta_productos activos_fijos stock_maquinaria equipo_computo terr_edif form_K"
foreach r of local varsz {
	capture gen `r'R=`r'
	capture gen `r'_WR=`r'_W
}
gen e17TODROP=e17
tostring e17TODROP, replace
forv p=1/6 {
	gen sector`p'dig=substr(e17TODROP,1,`p')
	sort sector`p'dig
	
	merge sector`p'dig using "Prices 2018 `p'dig.dta"
	drop if _merge==2
	replace salarios_tot=salarios_totR/p_wages if _merge==3
	replace salarios_blue=salarios_blueR/p_wages if _merge==3
	replace salarios_white=salarios_whiteR/p_wages if _merge==3

	replace MatPrima_reventa=MatPrima_reventaR/p_tradeE if _merge==3
	replace MatPrima_servicios=MatPrima_serviciosR/p_servE if _merge==3
	replace MatPrima_produccion=MatPrima_produccionR/p_manufE if _merge==3

	replace combustibles=combustiblesR/p_gas if _merge==3
	replace electricidad=electricidadR/p_electr if _merge==3
	replace renta_muebEinmue=renta_muebEinmueR/p_build if _merge==3
	*replace renta_inmuebles=renta_inmueblesR/p_build if _merge==3

	replace ingresos_ByS=ingresos_BySR/p_overallR if _merge==3
	replace ingresos_reventa=ingresos_reventaR/p_tradeR if _merge==3
	replace ingresos_servicios=ingresos_serviciosR/p_servR if _merge==3
	replace Venta_productos=Venta_productosR/p_manufR if _merge==3

	replace activos_fijos=activos_fijosR/p_Ktot if _merge==3
	replace stock_maquinaria=stock_maquinariaR/p_Kmach if _merge==3
	replace equipo_computo=equipo_computoR/p_Kcomp if _merge==3
	replace terr_edif=terr_edifR/p_Kbuild if _merge==3
	replace form_K=form_KR/p_Kinv if _merge==3
	
	replace salarios_tot_W=salarios_tot_WR/p_wages if _merge==3
	replace salarios_blue_W=salarios_blue_WR/p_wages if _merge==3
	replace salarios_white_W=salarios_white_WR/p_wages if _merge==3

	replace MatPrima_reventa_W=MatPrima_reventa_WR/p_tradeE if _merge==3
	replace MatPrima_servicios_W=MatPrima_servicios_WR/p_servE if _merge==3
	replace MatPrima_produccion_W=MatPrima_produccion_WR/p_manufE if _merge==3

	replace combustibles_W=combustibles_WR/p_gas if _merge==3
	replace electricidad_W=electricidad_WR/p_electr if _merge==3
	replace renta_muebEinmue_W=renta_muebEinmue_WR/p_build if _merge==3
	*replace renta_inmuebles_W=renta_inmuebles_WR/p_build if _merge==3

	replace ingresos_ByS_W=ingresos_ByS_WR/p_overallR if _merge==3
	replace ingresos_reventa_W=ingresos_reventa_WR/p_tradeR if _merge==3
	replace ingresos_servicios_W=ingresos_servicios_WR/p_servR if _merge==3
	replace Venta_productos_W=Venta_productos_WR/p_manufR if _merge==3

	replace activos_fijos_W=activos_fijos_WR/p_Ktot if _merge==3
	replace stock_maquinaria_W=stock_maquinaria_WR/p_Kmach if _merge==3
	replace equipo_computo_W=equipo_computo_WR/p_Kcomp if _merge==3
	replace terr_edif_W=terr_edif_WR/p_Kbuild if _merge==3
	replace form_K_W=form_K_WR/p_Kinv if _merge==3
	drop p_wages p_overallR p_manufR p_tradeR p_servR p_Ktot p_Kmach p_Kcomp p_Kbuild p_Kinv p_manufE p_tradeE p_servE p_gas p_electr p_build _merge sector`p'dig
}

local varsz "salarios_tot salarios_blue salarios_white MatPrima_reventa MatPrima_servicios MatPrima_produccion combustibles electricidad renta_muebEinmue renta_inmuebles ingresos_ByS ingresos_reventa ingresos_servicios Venta_productos activos_fijos stock_maquinaria equipo_computo terr_edif form_K"
foreach r of local varsz {
	capture drop `r'R
	capture drop `r'_WR
}
capture drop e17TODROP

*Convert to USD
local varsz "salarios_tot salarios_blue salarios_white MatPrima_reventa MatPrima_servicios MatPrima_produccion combustibles electricidad renta_muebEinmue renta_inmuebles ingresos_ByS ingresos_reventa ingresos_servicios Venta_productos activos_fijos stock_maquinaria equipo_computo terr_edif form_K"
foreach r of local varsz {
	replace `r'=`r'/12.7724
	replace `r'_W=`r'_W/12.7724
}

gen anio=2018
gen exists=1

compress
tempfile temp2018
save `temp2018'

*********************************************************************
**Step 2: Open 2014 Census
*********************************************************************

*Open file
use id_uelm e03 e04 e05 e06 e07 e17 ${vars2014} using "${insumosdir}\${file14}", clear
duplictes drop id_uelm, force
drop if substr(e17,1,1)=="1" | substr(e17,1,1)=="2"

*Create variables to identify manzanas and AGEBs
gen cve_ageb= e03+ e04+ e05+ e06
gen cve_agebmza= e03+ e04+ e05+ e06 + e07

**Doublecheck ids are properly coded
gen id=length(cve_ageb)
tab id
gen id2=length(cve_agebmza)
tab id2
replace e07="000" if e07==""
replace e07="00"+e07 if id2==14
replace e07="0"+e07 if id2==15

**Correct if id incomplete
replace cve_agebmza= e03+ e04+ e05+ e06 + e07

**Check for errors
assert length(cve_agebmza)==16

**Drop provisional vars
capture drop id id2

**Create a localidad clave, we will keep only localidades where the Habitat program was implemented
gen cve_localidad=substr(cve_agebmza,1,9)

**Merge with file including localities
merge m:1 cve_localidad using "${routeLocs}", keep(match) nogenerate
capture drop localidad_nobs

**Merge with 2014 manzanas existing in Habitat
sort cve_agebmza
merge cve_agebmza using "${routeMzas14}"
tab _merge
drop if _merge==2
drop _merge

***Rename vars
rename	h001a	personal_ocup
rename	h000a	personal_dep
rename	h010a	personal_remun
rename	h101a	personal_blue
rename	h203a	personal_white
rename 	j000a	salarios_tot
rename	j010a	salarios_blue
rename	j203a	salarios_white
rename	m000a	ingresos_ByS
rename	m010a	ingresos_reventa
rename	m020a	ingresos_servicios
rename	m030a	Venta_productos
rename	q000a	activos_fijos
rename	q400a	equipo_computo
rename	q010a	stock_maquinaria
rename	a221a	form_K
rename	k010a	MatPrima_reventa
rename	k020a	MatPrima_servicios
rename	k030a	MatPrima_produccion 
rename	k040a	combustibles
rename	k041a	electricidad

*Create sector (manufacturing, commerce, services)	IDs according to NAICS 2 digit level
gen scian=substr(e17,1,2)
destring scian, replace

gen sector=., after(e17)
replace sector=1 if scian>=31 & scian<=33	//Manufacturing
replace sector=2 if scian>=43 & scian<=46	//Commerce
replace sector=3 if scian>46 & scian!=.		//Services
drop scian

**Set varlist of variables to be cleaned (strategy: manzanas located are cleaned,
*** by group: if they belong to treatment, control or are outside of polygons.
** Variables are winsorized at 1% level at the upper tail, and at the lower tail if variables are not nonnegative.

ds
local a=r(varlist)
local b id_uelm e03 e04 e05 e06 e07 e17 cve_ageb cve_agebmza cve_localidad IDH_manzana IDH_polygon RCT_status sector
local c:list a-b

**Winsorize control, treatment and not in Habitat groups separately
replace RCT_status=2 if RCT_status==.
foreach var of local c {
	forv x=0/2 {
		gen `var'_WV`x'=`var' if RCT_status==`x'
		sum `var'_WV`x', detail
		replace `var'_WV`x'=r(p99) if `var'_WV`x'>r(p99) & `var'_WV`x'!=.
		if r(min)<0 {
			replace `var'_WV`x'=r(p1) if `var'_WV`x'<r(p1) & `var'_WV`x'!=.
		}
	}
	gen `var'_W=.
	replace `var'_W=`var'_WV0 if RCT_status==0
	replace `var'_W=`var'_WV1 if RCT_status==1
	replace `var'_W=`var'_WV2 if RCT_status==2
	drop `var'_WV0 `var'_WV1 `var'_WV2
	sum `var' `var'_W
}
replace RCT_status=. if RCT_status==2

*Convert to USD
local varsz "salarios_tot salarios_blue salarios_white MatPrima_reventa MatPrima_servicios MatPrima_produccion combustibles electricidad renta_muebEinmue renta_inmuebles ingresos_ByS ingresos_reventa ingresos_servicios Venta_productos activos_fijos stock_maquinaria equipo_computo terr_edif form_K"
foreach r of local varsz {
	replace `r'=`r'/12.7724
	replace `r'_W=`r'_W/12.7724
}

gen anio=2013
gen exists=1

compress
tempfile temp2014
save `temp2014'

*********************************************************************
**Step 3: Open 2009 Census
*********************************************************************

*Open file
use id_uelm e03 e04 e05 e06 e07 e17 ${vars2009} using "${insumosdir}\${file09}", clear
duplictes drop id_uelm, force
drop if substr(e17,1,1)=="1" | substr(e17,1,1)=="2"

*Create variables to identify manzanas and AGEBs
gen cve_ageb= e03+ e04+ e05+ e06
gen cve_agebmza= e03+ e04+ e05+ e06 + e07

**Doublecheck ids are properly coded
gen id=length(cve_ageb)
tab id
gen id2=length(cve_agebmza)
tab id2
replace e07="000" if e07==""
replace e07="00"+e07 if id2==14
replace e07="0"+e07 if id2==15

**Correct if id incomplete
replace cve_agebmza= e03+ e04+ e05+ e06 + e07

**Check for errors
assert length(cve_agebmza)==16

**Drop provisional vars
capture drop id id2

**Create a localidad clave, we will keep only localidades where the Habitat program was implemented
gen cve_localidad=substr(cve_agebmza,1,9)

**Merge with file including localities
merge m:1 cve_localidad using "${routeLocs}", keep(match) nogenerate
capture drop localidad_nobs

**Merge with 2009 manzanas existing in Habitat
sort cve_agebmza
merge cve_agebmza using "${routeMzas09}"
tab _merge
drop if _merge==2
drop _merge

***Rename vars
rename	h001a	personal_ocup
rename	h000a	personal_dep
rename	h010a	personal_remun
rename	h101a	personal_blue
rename	h200a	personal_white
rename 	j000a	salarios_tot
rename	j100a	salarios_blue
rename	j200a	salarios_white
rename	m000a	ingresos_ByS
rename	m100a	ingresos_reventa
rename	m200a	ingresos_servicios
rename	m300a	Venta_productos
rename	q000a	activos_fijos
rename	q400a	equipo_computo
rename	q101a	stock_maquinaria
rename	a221a	form_K
rename	k100a	MatPrima_reventa
rename	k200a	MatPrima_servicios
rename	k300	MatPrima_produccion 
rename	k411a	combustibles
rename	k412a	electricidad

*Create sector (manufacturing, commerce, services)	IDs according to NAICS 2 digit level
gen scian=substr(e17,1,2)
destring scian, replace

gen sector=., after(e17)
replace sector=1 if scian>=31 & scian<=33	//Manufacturing
replace sector=2 if scian>=43 & scian<=46	//Commerce
replace sector=3 if scian>46 & scian!=.		//Services
drop scian

**Set varlist of variables to be cleaned (strategy: manzanas located are cleaned,
*** by group: if they belong to treatment, control or are outside of polygons.
** Variables are winsorized at 1% level at the upper tail, and at the lower tail if variables are not nonnegative.

ds
local a=r(varlist)
local b id_uelm e03 e04 e05 e06 e07 e17 cve_ageb cve_agebmza cve_localidad IDH_manzana IDH_polygon RCT_status sector
local c:list a-b

**Winsorize control, treatment and not in Habitat groups separately
replace RCT_status=2 if RCT_status==.
foreach var of local c {
	forv x=0/2 {
		gen `var'_WV`x'=`var' if RCT_status==`x'
		sum `var'_WV`x', detail
		replace `var'_WV`x'=r(p99) if `var'_WV`x'>r(p99) & `var'_WV`x'!=.
		if r(min)<0 {
			replace `var'_WV`x'=r(p1) if `var'_WV`x'<r(p1) & `var'_WV`x'!=.
		}
	}
	gen `var'_W=.
	replace `var'_W=`var'_WV0 if RCT_status==0
	replace `var'_W=`var'_WV1 if RCT_status==1
	replace `var'_W=`var'_WV2 if RCT_status==2
	drop `var'_WV0 `var'_WV1 `var'_WV2
	sum `var' `var'_W
}
replace RCT_status=. if RCT_status==2

****************** Applying price indexes to values measure in money **********
	**By 6dig sector and variable	(most disaggregated price indexes, takes into account sector(6dig) and variables)

	*Strategy: Apply price indexes to variables starting from the most aggregate
		* Winsorized and Raw variables are kept. 
*******************************************************************************


local varsz "salarios_tot salarios_blue salarios_white MatPrima_reventa MatPrima_servicios MatPrima_produccion combustibles electricidad renta_muebEinmue renta_inmuebles ingresos_ByS ingresos_reventa ingresos_servicios Venta_productos activos_fijos stock_maquinaria equipo_computo terr_edif form_K"
foreach r of local varsz {
	capture gen `r'R=`r'
	capture gen `r'_WR=`r'_W
}

gen e17TODROP=e17
tostring e17TODROP, replace

forv p=1/6 {
	gen sector`p'dig=substr(e17TODROP,1,`p')
	sort sector`p'dig
	
	capture drop _merge
	merge sector`p'dig using "Prices 2008 `p'dig.dta"
	drop if _merge==2

	replace salarios_tot=salarios_totR/p_wages if _merge==3
	replace salarios_blue=salarios_blueR/p_wages if _merge==3
	replace salarios_white=salarios_whiteR/p_wages if _merge==3

	replace MatPrima_reventa=MatPrima_reventaR/p_tradeE if _merge==3
	replace MatPrima_servicios=MatPrima_serviciosR/p_servE if _merge==3
	replace MatPrima_produccion=MatPrima_produccionR/p_manufE if _merge==3

	replace combustibles=combustiblesR/p_gas if _merge==3
	replace electricidad=electricidadR/p_electr if _merge==3
	replace renta_muebEinmue=renta_muebEinmueR/p_build if _merge==3
	*replace renta_inmuebles=renta_inmueblesR/p_build if _merge==3

	replace ingresos_ByS=ingresos_BySR/p_overallR if _merge==3
	replace ingresos_reventa=ingresos_reventaR/p_tradeR if _merge==3
	replace ingresos_servicios=ingresos_serviciosR/p_servR if _merge==3
	replace Venta_productos=Venta_productosR/p_manufR if _merge==3

	replace activos_fijos=activos_fijosR/p_Ktot if _merge==3
	replace stock_maquinaria=stock_maquinariaR/p_Kmach if _merge==3
	replace equipo_computo=equipo_computoR/p_Kcomp if _merge==3
	replace terr_edif=terr_edifR/p_Kbuild if _merge==3
	replace form_K=form_KR/p_Kinv if _merge==3
	
	replace salarios_tot_W=salarios_tot_WR/p_wages if _merge==3
	replace salarios_blue_W=salarios_blue_WR/p_wages if _merge==3
	replace salarios_white_W=salarios_white_WR/p_wages if _merge==3

	replace MatPrima_reventa_W=MatPrima_reventa_WR/p_tradeE if _merge==3
	replace MatPrima_servicios_W=MatPrima_servicios_WR/p_servE if _merge==3
	replace MatPrima_produccion_W=MatPrima_produccion_WR/p_manufE if _merge==3

	replace combustibles_W=combustibles_WR/p_gas if _merge==3
	replace electricidad_W=electricidad_WR/p_electr if _merge==3
	replace renta_muebEinmue_W=renta_muebEinmue_WR/p_build if _merge==3
	*replace renta_inmuebles_W=renta_inmuebles_WR/p_build if _merge==3

	replace ingresos_ByS_W=ingresos_ByS_WR/p_overallR if _merge==3
	replace ingresos_reventa_W=ingresos_reventa_WR/p_tradeR if _merge==3
	replace ingresos_servicios_W=ingresos_servicios_WR/p_servR if _merge==3
	replace Venta_productos_W=Venta_productos_WR/p_manufR if _merge==3

	replace activos_fijos_W=activos_fijos_WR/p_Ktot if _merge==3
	replace stock_maquinaria_W=stock_maquinaria_WR/p_Kmach if _merge==3
	replace equipo_computo_W=equipo_computo_WR/p_Kcomp if _merge==3
	replace terr_edif_W=terr_edif_WR/p_Kbuild if _merge==3
	replace form_K_W=form_K_WR/p_Kinv if _merge==3

	drop p_wages p_overallR p_manufR p_tradeR p_servR p_Ktot p_Kmach p_Kcomp p_Kbuild p_Kinv p_manufE p_tradeE p_servE p_gas p_electr p_build _merge sector`p'dig
}

local varsz "salarios_tot salarios_blue salarios_white MatPrima_reventa MatPrima_servicios MatPrima_produccion combustibles electricidad renta_muebEinmue renta_inmuebles ingresos_ByS ingresos_reventa ingresos_servicios Venta_productos activos_fijos stock_maquinaria equipo_computo terr_edif form_K"
foreach r of local varsz {
	capture drop `r'R
	capture drop `r'_WR
}
capture drop e17TODROP

*Convert to USD
local varsz "salarios_tot salarios_blue salarios_white MatPrima_reventa MatPrima_servicios MatPrima_produccion combustibles electricidad renta_muebEinmue renta_inmuebles ingresos_ByS ingresos_reventa ingresos_servicios Venta_productos activos_fijos stock_maquinaria equipo_computo terr_edif form_K"
foreach r of local varsz {
	replace `r'=`r'/12.7724
	replace `r'_W=`r'_W/12.7724
}

gen anio=2008
gen exists=1

compress

*******************************************************************
**Step 4: Merge 2009, 2014 and 2018 censuses into a single database
*******************************************************************
append using `temp2014'
capture macro drop temp2014
append using `temp2018'
capture macro drop temp2018


**Generate constructed vars
gen salarios = salarios_blue + salarios_white	
gen ingresos_act = ingresos_reventa + ingresos_servicios + Venta_productos
gen gastos_act = MatPrima_reventa + MatPrima_servicios + MatPrima_produccion
gen gastos_energia = combustibles + electricidad
gen VA = ingresos_act - (gastos_act + gastos_energia)

gen salarios_W = salarios_blue_W + salarios_white_W
gen ingresos_act_W = ingresos_reventa_W + ingresos_servicios_W + Venta_productos_W
gen gastos_act_W = MatPrima_reventa_W + MatPrima_servicios_W + MatPrima_produccion_W
gen gastos_energia_W = combustibles_W + electricidad_W
gen VA_W = ingresos_act_W - (gastos_act_W + gastos_energia_W)

***Reestimate paid workers
gen personal_ocup2=personal_ocup+1, after(personal_ocup)
gen personal_dep2=personal_dep+1, after(personal_dep)
gen personal_remun2=personal_remun+1, after(personal_remun)


gen personal_ocup2_W=personal_ocup_W+1, after(personal_ocup_W)
gen personal_dep2_W=personal_dep_W+1, after(personal_dep_W)
gen personal_remun2_W=personal_remun_W+1, after(personal_remun_W)

**Drop intermediate variables
drop	ingresos_reventa*
drop	ingresos_servicios*
drop	Venta_productos*
drop	electricidad*
drop	combustibles*
drop	MatPrima*

***Create per capita variables

*No treatment vars
gen ingresos_actPROM=ingresos_act/personal_ocup
gen ingresos_actPROM2=ingresos_act/personal_ocup2
gen ingresos_actPROM3=ingresos_act/personal_remun2
gen VAPROM=VA/personal_ocup
gen VAPROM2=VA/personal_ocup2
gen VAPROM3=VA/personal_remun2
gen activos_fijosPROM=activos_fijos/personal_ocup
gen activos_fijosPROM2=activos_fijos/personal_ocup2
gen activos_fijosPROM3=activos_fijos/personal_remun2
gen salariosPROM=salarios/personal_remun
gen salarios_bluePROM=salarios_blue/personal_blue
gen salarios_whitePROM=salarios_white/personal_white

*Winsorized vars
gen ingresos_actPROM_W=ingresos_act_W/personal_ocup_W
gen ingresos_actPROM2_W=ingresos_act_W/personal_ocup2_W
gen ingresos_actPROM3_W=ingresos_act_W/personal_remun2_W
gen VAPROM_W=VA_W/personal_ocup_W
gen VAPROM2_W=VA_W/personal_ocup2_W
gen VAPROM3_W=VA_W/personal_remun2_W
gen activos_fijosPROM_W=activos_fijos_W/personal_ocup_W
gen activos_fijosPROM2_W=activos_fijos_W/personal_ocup2_W
gen activos_fijosPROM3_W=activos_fijos_W/personal_remun2_W
gen salariosPROM_W=salarios_W/personal_remun_W
gen salarios_bluePROM_W=salarios_blue_W/personal_blue_W
gen salarios_whitePROM_W=salarios_white_W/personal_white_W

****Re-ordering of vars
ds
local a=r(varlist)
local b "id_uelm anio"
local c:list a-b

reshape wide `c', i(id_uelm) j(anio)

local liista "e03 e04 e05 e06 e07 e17 sector cve_ageb cve_agebmza cve_localidad IDH_manzana IDH_polygon RCT_status"
foreach x of local liista {
	gen `x'=`x'2013
	capture replace `x'=`x'2008 if `x'==.
	capture replace `x'=`x'2008 if `x'==""
	capture replace `x'=`x'2018 if `x'==. & `x'2008==.
	capture replace `x'=`x'2018 if `x'=="" & `x'2018==""
}

order id_uelm e03 e04 e05 e06 e07 e17 sector cve_ageb cve_agebmza cve_localidad IDH_manzana IDH_polygon RCT_status exists2008 exists2013 exists2018
order e032008 e042008 e052008 e062008 e072008 e172008 sector2008 cve_ageb2008 cve_agebmza2008 cve_localidad2008 IDH_manzana2008 IDH_polygon2008 RCT_status2008 e032013 e042013 e052013 e062013 e072013 e172013 sector2013 cve_ageb2013 cve_agebmza2013 cve_localidad2013 IDH_manzana2013 IDH_polygon2013 RCT_status2013 e032018 e042018 e052018 e062018 e072018 e172018 sector2018 cve_ageb2018 cve_agebmza2018 cve_localidad2018 IDH_manzana2018 IDH_polygon2018 RCT_status2018, last

local lissta "VA ingresos_act ingresos_ByS activos_fijos stock_maquinaria equipo_computo form_K gastos_act gastos_energia VAPROM ingresos_actPROM activos_fijosPROM personal_dep personal_ocup personal_remun personal_blue personal_white salarios salarios_tot salarios_blue salarios_white salariosPROM salarios_bluePROM salarios_whitePROM"
local types "2018 2013 2008 _W2018 _W2013 _W2008"

foreach y of local types {
	local ej ""
	foreach x of local lissta {
		local ej "`ej' `x'`y'"
	}
	order `ej', after(RCT_status)
}

compress

**Add labels to variables
capture label variable id_uelm "CLEE"
capture label variable IDH_manzana "Manzana ID"
capture label variable IDH_polygon "Habitat poligono ID"
capture label variable RCT_status "Control=0 Treatment=1"
capture label variable sector "Industry (broad) ID"
capture label variable cve_localidad "Localidad ID (CE 2014)"

capture label variable e03 "State ID (CE 2014)"
capture label variable e04 "Municipality ID (CE 2014)"
capture label variable e05 "Localidad ID (CE 2014)"
capture label variable e06 "AGEB ID (CE 2014)"
capture label variable e07 "Manzana ID (CE 2014)"
capture label variable e17 "NAICS 6 digit (2013)"
capture label variable cve_ageb "AGEB ID (13-digit)"
capture label variable cve_agebmza "Manzana ID (16-digit)"

capture label variable exists2008 "Firm existed in 2008"
capture label variable exists2013 "Firm existed in 2013"
capture label variable exists2013 "Firm existed in 2018"

gen survivor20082013=(exists2008==1 & exists2013==1)
gen exiter20082013=(exists2008==1 & exists2013==.)
gen entrant20082013=(exists2008==. & exists2013==1)

gen survivor20132018=(exists2013==1 & exists2018==1)
gen exiter20132018=(exists2013==1 & exists2018==.)
gen entrant20132018=(exists2013==. & exists2018==1)

gen survivor20082018=(exists2008==1 & exists2018==1)
gen exiter20082018=(exists2008==1 & exists2018==.)
gen entrant20082018=(exists2008==. & exists2018==1)

gen inHabitat=(RCT_status!=.)
tab RCT_status inHabitat

egen idMUN=group(cve_mun)
rename IDH_polygon IDH_polygonSTR
egen IDH_polygon=group(IDH_polygonSTR)
gen control=(RCT_status==0) if RCT_status!=.

sort id_uelm
save "${datadir}\DB_Firms_all.dta", replace

global mainfile "DB_Firms_all.dta"
