
local ringtype="D"	// <-- Doughnut (i.e. A spillover ring at a certain range of distance of Habitat polygons (e.g. 100m to 250m from polygon))
local ringarea="D"	// <-- Dissolved (i.e. actual area covered by treat or control area)
local cluster="A"	// <-- Clustered by AGEB
local ccoverage="O"	// <-- Buffer area only (e.g. 100m buffer)

capture use "${supportdir}\\PolygonSize_sqm_z.dta", clear
if _rc!=0 {
	use "${supportdir}\\PolygonSize_sqm.dta", clear
	*creating z-scored indexes of market access
	foreach x in areapolm {
		egen `x'_m = mean(`x')
		egen `x'_sd = sd(`x')
		replace `x' = (`x' - `x'_m)/`x'_sd
		}
	drop *_m *_sd //
	compress
	sort IDH_polygon
	save "${supportdir}\\PolygonSize_sqm_z.dta", replace
}

capture erase "T9 Spillover Regs.txt"
capture erase "T9 Spillover Regs.xls"

local varlistA "ingresos_act_W activos_fijos_W salarios_W personal_remun2_W"		//Local with vars for regression

local q=3 //--> Selection of period: 2008-2018
local distances "100m 250m 500m 1km"
foreach k of local distances {
	*Erasing possible old output

	use ///
		cve_agebmza cve_ageb cve_mun IDH_polygon RCT_status survivor* entrant* exiter* sector e17 exists* size_* ///
		ingresos_act_W2* activos_fijos_W2* salarios_W2* ///
		personal_remun2_W* ///
		${varselect_`ringtype'`ringarea'`ccoverage'_`k'} ///
		if ${buffsel_`ringtype'`ringarea'`ccoverage'_`k'} ///
	using "${insumosdir}\\${mainfile}", clear

	gen uniqueid=_n

	/*Modify in database master do file*/
	capture drop idMUN
	egen idMUN=group(cve_mun)
	assert idMUN!=.
	egen ageblev=group(cve_ageb)
	/*Modify in database master do file*/

	capture drop IDH_polygon
	joinby cve_agebmza using "${supportdir}\\BuffDatabaseD_`k'.dta" //Doughnut
	rename IDH_polygon`k' IDH_polygon
	sort IDH_polygon
	merge IDH_polygon using "${supportdir}\\Access to transport.dta" //Doughnut
	drop _merge
	sort IDH_polygon
	merge IDH_polygon using "${supportdir}\\PolygonSize_sqm_z.dta" //Doughnut
	drop _merge
	sort IDH_polygon
	merge IDH_polygon using "${supportdir}\\market_access_measures.dta" //Doughnut
	drop _merge

	rename IDH_polygon IDH_polygonSTR
	egen IDH_polygon=group(IDH_polygonSTR)

	collapse (mean) dist_transport_z areapolm wealth_adj_street_z pobtot_adj_street_z, by(uniqueid)

	sort uniqueid
	compress
	capture erase "tempie tempie tempie for spill `k'.dta"
	save "tempie tempie tempie for spill `k'.dta", replace

	use ///
		cve_agebmza cve_ageb cve_mun IDH_polygon RCT_status survivor* entrant* exiter* sector e17 exists* size_* ///
		ingresos_act_W2* activos_fijos_W2* salarios_W2* ///
		personal_remun2_W* ///
		${varselect_`ringtype'`ringarea'`ccoverage'_`k'} ///
		if ${buffsel_`ringtype'`ringarea'`ccoverage'_`k'} ///
	using "${insumosdir}\\${mainfile}", clear
	
	gen uniqueid=_n
	sort uniqueid
	merge uniqueid using "tempie tempie tempie for spill `k'.dta"
	keep if _merge==3
	drop _merge
	erase "tempie tempie tempie for spill `k'.dta"

	sort cve_ageb
	merge cve_ageb using "${supportdir}\\AGEBs closer to polygon.dta"
	keep if _merge==3
	drop _merge
	
	replace treat`ringtype'_b`k'_`ringarea'=1 if (treat`ringtype'_b`k'_`ringarea'>0 & treat`ringtype'_b`k'_`ringarea'!=.)
	replace all`ringtype'_b`k'_`ringarea'=1 if (all`ringtype'_b`k'_`ringarea'>0 & all `ringtype'_b`k'_`ringarea'!=.)
	
	gen dist_transport_z_treat=treat`ringtype'_b`k'_`ringarea'*dist_transport_z
	gen dist_transport_z_all=all`ringtype'_b`k'_`ringarea'*dist_transport_z
	label variable dist_transport_z "Access to transport"
	label variable dist_transport_z_treat "Transport*Treatment"
	label variable dist_transport_z_all "Transport*Any"

	gen areapolm_treat=treat`ringtype'_b`k'_`ringarea'*areapolm
	gen areapolm_all=all`ringtype'_b`k'_`ringarea'*areapolm
	label variable areapolm "Size of polygon"
	label variable areapolm_treat "Size*Treatment"
	label variable areapolm_all "Size*Any"

	gen pobtot_treat=treat`ringtype'_b`k'_`ringarea'*pobtot_adj_street_z
	gen pobtot_all=all`ringtype'_b`k'_`ringarea'*pobtot_adj_street_z
	label variable pobtot_adj_street_z "Population Density"
	label variable pobtot_treat "PopDens*Treatment"
	label variable pobtot_all "PopDens*Any"

	gen wealth_treat=treat`ringtype'_b`k'_`ringarea'*wealth_adj_street_z
	gen wealth_all=all`ringtype'_b`k'_`ringarea'*wealth_adj_street_z
	label variable wealth_adj_street_z "Wealth Index"		
	label variable wealth_treat "Wealth*Treatment"
	label variable wealth_all "Wealth*Any"
	
	rename treat`ringtype'_b`k'_`ringarea' treat
	label variable treat "Treatment buffer"
	rename all`ringtype'_b`k'_`ringarea' all
	label variable all "Any buffer"

	egen manzanalev=group(cve_agebmza)
	egen ageblev=group(cve_ageb)
	egen idMUN=group(cve_mun)
	assert idMUN!=.
	assert manzanalev!=.
	assert ageblev!=.
	capture drop control

	gen control=(treat==0 & all>0) if (treat!=. & all!=.)

	local w=1
	keep if ${csector`w'}
	local d=1

	foreach z of local varlistA {
		*4. Run variable-Habitat regressions for entrants
			*a. Get control mean to later include in regression table
		capture scalar drop controlmean_scalar
		capture matrix drop controlmean_matrix
		capture reg `z'${etime`q'} control if entrant${stime`q'}${etime`q'}==1 & exists${etime`q'}==1, robust noconstant
		if _rc==0 {
			matrix controlmean_matrix=get(_b)
			scalar controlmean_scalar=controlmean_matrix[1,1]
			local controlmean_local=scalar(controlmean_scalar)

			*b. Run main regression
			capture noisily reg `z'${etime`q'} treat ${interactcomm`d'} i.idMUN if e(sample), cluster(BelongsToPolygon)
			outreg2 using "T9 Spillover Regs.xls", append label excel dec(3) nocons nor2 cttop(Entrant,`k') keep(treat all ${interactcomm`d'}) adds("Control mean", `controlmean_local')
		}

		*Calculate polygon level mean at baseline (used as a substitute for variable level at baseline (lag))	
		bys ${clusterselect_`cluster'}: egen lagVAR=mean(`z'${stime`q'}) if ${csector`w'}
		label variable lagVAR "meanpolygonbaseline"

		*5. Run ANCOVA regressions for all firms
			*a. Get control mean to later include in regression table
		capture scalar drop controlmean_scalar
		capture matrix drop controlmean_matrix
		capture reg `z'${etime`q'} control if exists${etime`q'}==1, robust noconstant
		if _rc==0 {
			matrix controlmean_matrix=get(_b)
			scalar controlmean_scalar=controlmean_matrix[1,1]
			local controlmean_local=scalar(controlmean_scalar)

			*b. Run main regression
			capture noisily reg `z'${etime`q'} treat ${interactcomm`d'} lagVAR i.idMUN if e(sample), cluster(BelongsToPolygon)
			outreg2 using "T9 Spillover Regs.xls", append label excel dec(3) nocons nor2 cttop(All firms,`k') keep(treat all ${interactcomm`d'}) adds("Control mean", `controlmean_local')
		}

		*6. Run ANCOVA regressions for surviving firms
			*a. Get control mean to later include in regression table
		capture scalar drop controlmean_scalar
		capture matrix drop controlmean_matrix
		capture reg `z'${etime`q'} control if (exists${stime`q'}==1 & exists${etime`q'}==1) & survivor${stime`q'}${etime`q'}==1, robust noconstant
		if _rc==0 {
			matrix controlmean_matrix=get(_b)
			scalar controlmean_scalar=controlmean_matrix[1,1]
			local controlmean_local=scalar(controlmean_scalar)
			
			*b. Run main regression
			capture noisily reg `z'${etime`q'} treat ${interactcomm`d'} lagVAR i.idMUN if e(sample), cluster(BelongsToPolygon)
			outreg2 using "T9 Spillover Regs.xls", append label excel dec(3) nocons nor2 cttop(Survivor,`k') keep(treat all ${interactcomm`d'}) adds("Control mean", `controlmean_local')
		}
		drop lagVAR
	}
}

capture erase "T9 Spillover Regs.txt"
