clear

global filesdir "C:\Users\luisf\OneDrive\Documents\WB\Stata\Habitat\2020 project relaunch\GIS post habitat"

cd "${filesdir}"

forv i=2013/2017 {
	quietly import delimited "IntersectControl`i'.csv", clear
	quietly keep idh_poly09
	quietly duplicates drop
	rename idh_poly09 IDH_polygon
	gen Treated`i'=1
	compress
	sort IDH_polygon
	save "tempieC`i'.dta", replace
}

forv i=2013/2017 {
	quietly import delimited "IntersectTreated`i'.csv", clear
	quietly keep idh_poly09
	quietly duplicates drop
	rename idh_poly09 IDH_polygon
	gen Treated`i'=1
	compress
	sort IDH_polygon
	save "tempieT`i'.dta", replace
}

forv i=2013/2017 {
	use "tempieC`i'.dta", clear
	append using "tempieT`i'.dta"
	sort IDH_polygon
	compress
	save "tempie`i'.dta", replace
	erase "tempieC`i'.dta"
	erase "tempieT`i'.dta"
}

	
use "PolygonDatabase.dta", clear
sort IDH_polygon
keep IDH_polygon-cve_mun
compress
save "tempie.dta", replace

use "PolygonDummiesv3.dta", clear
sort IDH_polygon
keep IDH_polygon size_*
merge IDH_polygon using "tempie.dta"
drop _merge
erase "tempie.dta"

sort IDH_polygon
destring IDH_polygon, replace

egen idMUN=group(cve_mun)

forv i=2013/2017 {
	sort IDH_polygon
	capture drop _merge
	merge IDH_polygon using "tempie`i'.dta"
	drop _merge
	replace Treated`i'=0 if Treated`i'==.
	erase "tempie`i'.dta"
}

*capture erase  "TA2 BTPostPolDumPval.xls"
*capture erase  "TA2 BTPostRawPval.xls"
capture erase "TA2 Balance Post.xls"

forv i=2013/2017 {

	quietly ttest Treated`i', by(RCT_status)
		capture scalar drop t1
		capture scalar drop t2
		capture scalar drop t3
		capture scalar drop t4
		capture scalar drop t5
		capture scalar drop t6
		scalar t1=r(mu_1)
		scalar t2=r(sd_1)/(sqrt(r(N_1)))
		scalar t3=r(N_1)
		scalar t4=r(mu_2)
		scalar t5=r(sd_2)/(sqrt(r(N_2)))
		scalar t6=r(N_2)
		mat tempT`i'=[scalar(t1),scalar(t2),scalar(t3),scalar(t4),scalar(t5),scalar(t6)]
		mat rownames tempT`i' = `i'
		mat colnames tempT`i' = Mean_Control StdError_Control Obs_Control Mean_Treatment StdError_Treatment Obs_Treatment

	quietly reg Treated`i' i.RCT_status size_1_100 size_101_200 size_201_500 size_501_1000 size_1001 i.idMUN, cluster(IDH_polygon)
		capture mat drop temp
		capture scalar drop a1
		capture scalar drop a2
		mat temp=r(table)
		scalar a1=temp[1,2]*(-1)
		scalar a2=temp[4,2]
		mat tempC`i'=[scalar(a1),scalar(a2)]
		mat rownames tempC`i' = `i'
		mat colnames tempC`i' = Diff_Conditional pvalue_Conditional

	quietly reg Treated`i' i.RCT_status, cluster(IDH_polygon)
		capture mat drop temp
		capture scalar drop a1
		capture scalar drop a2
		mat temp=r(table)
		scalar a1=temp[1,2]*(-1)
		scalar a2=temp[4,2]
		mat tempU`i'=[scalar(a1),scalar(a2)]
		mat rownames tempU`i' = `i'
		mat colnames tempU`i' = Diff_Unconditional pvalue_Unconditional

	if `i'==2013 {
		mat C=matrix(tempC`i')
		mat U=matrix(tempU`i')
		mat T=matrix(tempT`i')
	}
	else {
		mat C=[matrix(C)\matrix(tempC`i')]
		mat U=[matrix(U)\matrix(tempU`i')]
		mat T=[matrix(T)\matrix(tempT`i')]
	}
	mat drop tempC`i' tempU`i' tempT`i' temp
	scalar drop a1 a2 t1 t2 t3 t4 t5 t6
}
mat Results=[matrix(T),matrix(U),matrix(C)]

mat drop C U T
mat list Results

preserve
drop *
svmat Results, names(col)
gen year=_n+2012, before(Mean_Control)
export excel using "TA2 Balance Post.xls", firstrow(var) replace
restore



/* Old, cannot extract pvalues (only stars) from these commands*/

	*iebaltab_regcoeff1 Treated* , grpvar(RCT_status) vce(cluster IDH_polygon) fixedeffect(idMUN) ///
		covariates(size_1_100 size_101_200 size_201_500 size_501_1000 size_1001) save("TA2 BTPostPolDumPval.xls") replace
	*iebaltab_regcoeff1 Treated* , grpvar(RCT_status) vce(cluster IDH_polygon) fixedeffect(idMUN) ///
		save("TA2 BTPostRawPval.xls") replace
