****Habitat 2023: Descriptive statistics ****


*Set up computer's root directory.

capture sysdir set PERSONAL "Z:\Procesamiento\Trabajo\custom commands"
global maindir "Z:\Procesamiento\Trabajo"
global resdirtemptemp "Z:\Resultados"

global insumosdir "Z:\Procesamiento\Insumos\Censos Economicos"
global file09 "Insumo2009.dta"
global file14 "Insumo2014.dta"
global file19 "Insumo2019.dta"
global mainfile "HabitatDB(wBuffer).dta"
global bankingfile "HabitatFinanceSection.dta"

global cyear=substr(c(current_date),-4,.)
global cmonth=substr(c(current_date),4,3)
if real(substr(c(current_date),1,2))<10 {
	global cday="0"+substr(c(current_date),2,1)
}
else {
	global cday=substr(c(current_date),1,2)
}

if "$cmonth"=="Jan" global cmonth="01"
else if "$cmonth"=="Feb" global cmonth="02"
else if "$cmonth"=="Mar" global cmonth="03"
else if "$cmonth"=="Apr" global cmonth="04"
else if "$cmonth"=="May" global cmonth="05"
else if "$cmonth"=="Jun" global cmonth="06"
else if "$cmonth"=="Jul" global cmonth="07"
else if "$cmonth"=="Aug" global cmonth="08"
else if "$cmonth"=="Sep" global cmonth="09"
else if "$cmonth"=="Oct" global cmonth="10"
else if "$cmonth"=="Nov" global cmonth="11"
else if "$cmonth"=="Dec" global cmonth="12"

global resdirtemp "${resdirtemptemp}\CE-$cyear-$cmonth-$cday"

*******************************************************************
*******************************************************************
global restitle "BankAccessRegs (loan3)"
*******************************************************************
*******************************************************************
global resdir "${resdirtemp}-${restitle}"

capture shell rm -r "${resdir}"
capture mkdir "${resdir}"

cd "${resdir}"

#delimit ;
global carea1 " (RCT_status!=. | RCT_status==.)";	global tarea1 "All areas";
global carea2 " RCT_status!=.";	global tarea2 "Habitat";
global carea3 " RCT_status==.";	global tarea3 "Other areas"; 

global csample1 `"drop if substr(e17,1,1)=="1" | substr(e17,1,1)=="2""';	global tsample1 "New";
global csample2 " ";	global tsample2 "Old";

global csector1 " sector!=.";	global tsector1 "All sectors";
global csector2 " sector==1 ";	global tsector2 "Manufacturing";
global csector3 " sector!=1 ";	global tsector3 "Commerce and Services";

global stime1=2008;	global etime1=2013;
global stime2=2013;	global etime2=2018;
global stime3=2008;	global etime3=2018;
#delimit cr

local y=1
use ///
	if RCT_status!=. ///
using "${insumosdir}\\${bankingfile}", clear

${csample`y'}

capture drop idMUN
capture egen idMUN=group(cve_mun)

*rename IDH_polygon IDH_polygonSTR		//Setting Polygon ID var in numeric
*egen IDH_polygon=group(IDH_polygonSTR)		//Setting Polygon ID var in numeric
*sum IDH_polygon

capture gen control=(RCT_status==0) if RCT_status!=.	//Creating control group dummy variable (used to estimate control means)


#delimit ;
gen survivor20082013=survivor;	gen survivor20132018=survivor2;	gen survivor20082018=survivor3;
gen entrant20082013=entrant;	gen entrant20132018=entrant2;	gen entrant20082018=entrant3;
gen exiter20082013=exiter;	gen exiter20132018=exiter2;	gen exiter20082018=exiter3;
#delimit cr	

forv i=2008(5)2018 {
	gen loan3_a`i'=max(o521_1a`i',o521_2a`i')
	gen loan3_r`i'=max(o521_1r`i',o521_2r`i')
}

local varlistA "loan3_a o521_1a o521_2a loan3_r o521_1r o521_2r"		//Local with vars for regression

label variable RCT_status "Habitat"

***** Main regressions ****************
**************************************************

	**Gameplan:
		*1. Run exit status regressions
		*2. Run entry status regressions
		*3. Run ANCOVA regressions for all firms
		*4. Run ANCOVA regressions for surviving firms
		*5. Run variable-Habitat regressions for exiters
		*6. Run variable-Habitat regressions for entrants

		*Note: all regressions include polygon size and municipality fixed effects

forv q=1/3 {
	*Erasing possible old output
	capture erase "Regs exit${stime`q'}${etime`q'}${tsample`y'}.txt"
	capture erase "Regs entry${stime`q'}${etime`q'}${tsample`y'}.txt"

	capture erase "Regs exiter${stime`q'}${etime`q'}${tsample`y'}.txt"
	capture erase "Regs entrant${stime`q'}${etime`q'}${tsample`y'}.txt"

	capture erase "Regs firms${stime`q'}${etime`q'}${tsample`y'}.txt"
	capture erase "Regs survivor${stime`q'}${etime`q'}${tsample`y'}.txt"

	capture erase "Regs exit${stime`q'}${etime`q'}${tsample`y'}.xls"
	capture erase "Regs entry${stime`q'}${etime`q'}${tsample`y'}.xls"

	capture erase "Regs exiter${stime`q'}${etime`q'}${tsample`y'}.xls"
	capture erase "Regs entrant${stime`q'}${etime`q'}${tsample`y'}.xls"

	capture erase "Regs firms${stime`q'}${etime`q'}${tsample`y'}.xls"
	capture erase "Regs survivor${stime`q'}${etime`q'}${tsample`y'}.xls"

	** Loop through sectors

	foreach z of local varlistA {
		forv w=1/3 {
			*3. Run variable-Habitat regressions for exiters
				*a. Get control mean to later include in regression table
			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg `z'${stime`q'} control if exiter${stime`q'}${etime`q'}==1 & exists${stime`q'}==1 & ${csector`w'}, robust noconstant
			capture matrix controlmean_matrix=get(_b)
			capture scalar controlmean_scalar=controlmean_matrix[1,1]
			capture local controlmean_local=scalar(controlmean_scalar)

				*b. Run main regression
			capture noisily reg `z'${stime`q'} RCT_status size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "Regs exiter${stime`q'}${etime`q'}${tsample`y'}.xls", append label excel dec(3) nocons nor2 cttop(${tsector`w'},All) keep(RCT_status) adds("Control mean", `controlmean_local')
			}


			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg `z'${stime`q'} control if exiter${stime`q'}${etime`q'}==1 & exists${stime`q'}==1 & ${csector`w'} & own_${stime`q'}==0, robust noconstant
			capture matrix controlmean_matrix=get(_b)
			capture scalar controlmean_scalar=controlmean_matrix[1,1]
			capture local controlmean_local=scalar(controlmean_scalar)

				*b. Run main regression
			capture noisily reg `z'${stime`q'} RCT_status size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "Regs exiter${stime`q'}${etime`q'}${tsample`y'}.xls", append label excel dec(3) nocons nor2 cttop(${tsector`w'},Not owner) keep(RCT_status) adds("Control mean", `controlmean_local')
			}


			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg `z'${stime`q'} control if exiter${stime`q'}${etime`q'}==1 & exists${stime`q'}==1 & ${csector`w'} & own_${stime`q'}==1, robust noconstant
			capture matrix controlmean_matrix=get(_b)
			capture scalar controlmean_scalar=controlmean_matrix[1,1]
			capture local controlmean_local=scalar(controlmean_scalar)

				*b. Run main regression
			capture noisily reg `z'${stime`q'} RCT_status size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "Regs exiter${stime`q'}${etime`q'}${tsample`y'}.xls", append label excel dec(3) nocons nor2 cttop(${tsector`w'},Owner) keep(RCT_status) adds("Control mean", `controlmean_local')
			}




			*4. Run variable-Habitat regressions for entrants
				*a. Get control mean to later include in regression table
			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg `z'${etime`q'} control if entrant${stime`q'}${etime`q'}==1 & exists${etime`q'}==1 & ${csector`w'}, robust noconstant
			capture matrix controlmean_matrix=get(_b)
			capture scalar controlmean_scalar=controlmean_matrix[1,1]
			capture local controlmean_local=scalar(controlmean_scalar)

				*b. Run main regression
			capture noisily reg `z'${etime`q'} RCT_status size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "Regs entrant${stime`q'}${etime`q'}${tsample`y'}.xls", append label excel dec(3) nocons nor2 cttop(${tsector`w'},All) keep(RCT_status) adds("Control mean", `controlmean_local')
			}




			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg `z'${etime`q'} control if entrant${stime`q'}${etime`q'}==1 & exists${etime`q'}==1 & ${csector`w'} & own_${etime`q'}==0, robust noconstant
			capture matrix controlmean_matrix=get(_b)
			capture scalar controlmean_scalar=controlmean_matrix[1,1]
			capture local controlmean_local=scalar(controlmean_scalar)

				*b. Run main regression
			capture noisily reg `z'${etime`q'} RCT_status size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "Regs entrant${stime`q'}${etime`q'}${tsample`y'}.xls", append label excel dec(3) nocons nor2 cttop(${tsector`w'},Not owner) keep(RCT_status) adds("Control mean", `controlmean_local')
			}



			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg `z'${etime`q'} control if entrant${stime`q'}${etime`q'}==1 & exists${etime`q'}==1 & ${csector`w'} & own_${etime`q'}==1, robust noconstant
			capture matrix controlmean_matrix=get(_b)
			capture scalar controlmean_scalar=controlmean_matrix[1,1]
			capture local controlmean_local=scalar(controlmean_scalar)

				*b. Run main regression
			capture noisily reg `z'${etime`q'} RCT_status size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "Regs entrant${stime`q'}${etime`q'}${tsample`y'}.xls", append label excel dec(3) nocons nor2 cttop(${tsector`w'},Owner) keep(RCT_status) adds("Control mean", `controlmean_local')
			}


		}
	}

	*Set loop for variables to analyse
	foreach z of local varlistA {
		** Loop through sectors
		forv w=1/3 {
			*Calculate polygon level mean at baseline (used as a substitute for variable level at baseline (lag))	
			capture bys IDH_polygon: egen lagVAR=mean(`z'${stime`q'}) if ${csector`w'}
			capture label variable lagVAR "meanpolygonbaseline"

			*5. Run ANCOVA regressions for all firms
				*a. Get control mean to later include in regression table
			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg `z'${etime`q'} control if exists${etime`q'}==1 & ${csector`w'}, robust noconstant
			capture matrix controlmean_matrix=get(_b)
			capture scalar controlmean_scalar=controlmean_matrix[1,1]
			capture local controlmean_local=scalar(controlmean_scalar)

				*b. Run main regression
			capture noisily reg `z'${etime`q'} RCT_status lagVAR size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "Regs firms${stime`q'}${etime`q'}${tsample`y'}.xls", append label excel dec(3) nocons nor2 cttop(${tsector`w'},All) keep(RCT_status) adds("Control mean", `controlmean_local')
			}

			*6. Run ANCOVA regressions for surviving firms
				*a. Get control mean to later include in regression table
			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg `z'${etime`q'} control if (exists${stime`q'}==1 & exists${etime`q'}==1) & survivor${stime`q'}${etime`q'}==1 & ${csector`w'}, robust noconstant
			capture matrix controlmean_matrix=get(_b)
			capture scalar controlmean_scalar=controlmean_matrix[1,1]
			capture local controlmean_local=scalar(controlmean_scalar)

				*b. Run main regression
			capture noisily reg `z'${etime`q'} RCT_status lagVAR size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "Regs survivor${stime`q'}${etime`q'}${tsample`y'}.xls", append label excel dec(3) nocons nor2 cttop(${tsector`w'},All) keep(RCT_status) adds("Control mean", `controlmean_local')
			}
			capture drop lagVAR




			capture bys IDH_polygon: egen lagVAR=mean(`z'${stime`q'}) if ${csector`w'} & own_${stime`q'}==0
			capture label variable lagVAR "meanpolygonbaseline"

			*5. Run ANCOVA regressions for all firms
				*a. Get control mean to later include in regression table
			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg `z'${etime`q'} control if exists${etime`q'}==1 & ${csector`w'} & own_${etime`q'}==0, robust noconstant
			capture matrix controlmean_matrix=get(_b)
			capture scalar controlmean_scalar=controlmean_matrix[1,1]
			capture local controlmean_local=scalar(controlmean_scalar)

				*b. Run main regression
			capture noisily reg `z'${etime`q'} RCT_status lagVAR size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "Regs firms${stime`q'}${etime`q'}${tsample`y'}.xls", append label excel dec(3) nocons nor2 cttop(${tsector`w'},Not owner) keep(RCT_status) adds("Control mean", `controlmean_local')
			}

			*6. Run ANCOVA regressions for surviving firms
				*a. Get control mean to later include in regression table
			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg `z'${etime`q'} control if (exists${stime`q'}==1 & exists${etime`q'}==1) & survivor${stime`q'}${etime`q'}==1 & ${csector`w'} & own_${etime`q'}==0, robust noconstant
			capture matrix controlmean_matrix=get(_b)
			capture scalar controlmean_scalar=controlmean_matrix[1,1]
			capture local controlmean_local=scalar(controlmean_scalar)

				*b. Run main regression
			capture noisily reg `z'${etime`q'} RCT_status lagVAR size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "Regs survivor${stime`q'}${etime`q'}${tsample`y'}.xls", append label excel dec(3) nocons nor2 cttop(${tsector`w'},Not owner) keep(RCT_status) adds("Control mean", `controlmean_local')
			}
			capture drop lagVAR



			capture bys IDH_polygon: egen lagVAR=mean(`z'${stime`q'}) if ${csector`w'} & own_${stime`q'}==1
			capture label variable lagVAR "meanpolygonbaseline"

			*5. Run ANCOVA regressions for all firms
				*a. Get control mean to later include in regression table
			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg `z'${etime`q'} control if exists${etime`q'}==1 & ${csector`w'} & own_${etime`q'}==1, robust noconstant
			capture matrix controlmean_matrix=get(_b)
			capture scalar controlmean_scalar=controlmean_matrix[1,1]
			capture local controlmean_local=scalar(controlmean_scalar)

				*b. Run main regression
			capture noisily reg `z'${etime`q'} RCT_status lagVAR size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "Regs firms${stime`q'}${etime`q'}${tsample`y'}.xls", append label excel dec(3) nocons nor2 cttop(${tsector`w'},Owner) keep(RCT_status) adds("Control mean", `controlmean_local')
			}

			*6. Run ANCOVA regressions for surviving firms
				*a. Get control mean to later include in regression table
			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg `z'${etime`q'} control if (exists${stime`q'}==1 & exists${etime`q'}==1) & survivor${stime`q'}${etime`q'}==1 & ${csector`w'} & own_${etime`q'}==1, robust noconstant
			capture matrix controlmean_matrix=get(_b)
			capture scalar controlmean_scalar=controlmean_matrix[1,1]
			capture local controlmean_local=scalar(controlmean_scalar)

				*b. Run main regression
			capture noisily reg `z'${etime`q'} RCT_status lagVAR size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "Regs survivor${stime`q'}${etime`q'}${tsample`y'}.xls", append label excel dec(3) nocons nor2 cttop(${tsector`w'},Owner) keep(RCT_status) adds("Control mean", `controlmean_local')
			}
			capture drop lagVAR

		}
	}

	*Erase txt files (undesired output of outreg2 command, xls files suffice)
	capture erase "Regs exit${stime`q'}${etime`q'}${tsample`y'}.txt"
	capture erase "Regs entry${stime`q'}${etime`q'}${tsample`y'}.txt"

	capture erase "Regs exiter${stime`q'}${etime`q'}${tsample`y'}.txt"
	capture erase "Regs entrant${stime`q'}${etime`q'}${tsample`y'}.txt"

	capture erase "Regs firms${stime`q'}${etime`q'}${tsample`y'}.txt"
	capture erase "Regs survivor${stime`q'}${etime`q'}${tsample`y'}.txt"

	**************************************************			
}





