
global npobtot_adj_street_z "Population density"
global nwealth_adj_street_z "Wealth index"
global nareapolm "Polygon size"
global ndist_transport_z "Driving distance to main road"

capture use "${supportdir}\\PolygonSize_sqm_z.dta", clear
if _rc!=0 {
	use "${supportdir}\\PolygonSize_sqm.dta", clear
	*creating z-scored indexes of market access
	foreach x in areapolm {
		egen `x'_m = mean(`x')
		egen `x'_sd = sd(`x')
		replace `x' = (`x' - `x'_m)/`x'_sd
		}
	drop *_m *_sd //
	compress
	sort IDH_polygon
	save "${supportdir}\\PolygonSize_sqm_z.dta", replace
}

use ///
	cve_mun IDH_polygon RCT_status survivor* entrant* exiter* sector e17 exists* size_* ///
		ingresos_act_W2* activos_fijos_W2* salarios_W2* ///
		personal_remun2_W2* ///
	if RCT_status!=. ///
using "${insumosdir}\\${mainfile}", clear

sort IDH_polygon
merge IDH_polygon using "${supportdir}\\Access to transport.dta" //Include distance to main road database
drop _merge
sort IDH_polygon
merge IDH_polygon using "${supportdir}\\PolygonSize_sqm_z.dta" //Size of polygon
drop _merge
sort IDH_polygon
merge IDH_polygon using "${supportdir}\\market_access_measures.dta" //Measure of population density and wealth
drop _merge

local varlistA "ingresos_act_W activos_fijos_W salarios_W personal_remun2_W"		//Local with vars for regression
local interacts "pobtot_adj_street_z wealth_adj_street_z areapolm dist_transport_z"
label variable RCT_status "Habitat"

*Erasing possible old output
capture erase "TA9 EntryExit MktAccess.txt"
capture erase "TA9 EntryExit MktAccess.xls"

foreach z of local varlistA {
	foreach q in 3 {
		foreach g of local interacts {
			capture drop TempVar
			capture drop TempInteract

			quietly gen TempVar=`g'
			quietly gen TempInteract=`g'*RCT_status
			label variable TempVar "Mkt Access var"
			label variable TempInteract "Interaction"

			*1. Run exit status regressions
				*a. Get control mean to later include in regression table
			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg exiter${stime`q'}${etime`q'} control if exists${stime`q'}==1, robust noconstant
			matrix controlmean_matrix=get(_b)
			scalar controlmean_scalar=controlmean_matrix[1,1]
			local controlmean_local=scalar(controlmean_scalar)

				*b. Run main regression
			capture noisily reg exiter${stime`q'}${etime`q'} TempInteract RCT_status TempVar  size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "TA9 ExitEntry MktAccess.xls", append label excel dec(3) nor2 nocons cttop(Pr(Exit), ${n`g'}) keep(TempInteract RCT_status TempVar) adds("Control mean", `controlmean_local')
			}

			*2. Run entry status regressions
				*a. Get control mean to later include in regression table
			capture scalar drop controlmean_scalar
			capture matrix drop controlmean_matrix
			capture reg entrant${stime`q'}${etime`q'} control if exists${etime`q'}==1, robust noconstant
			matrix controlmean_matrix=get(_b)
			scalar controlmean_scalar=controlmean_matrix[1,1]
			local controlmean_local=scalar(controlmean_scalar)
			
				*b. Run main regression
			capture noisily reg entrant${stime`q'}${etime`q'} TempInteract RCT_status TempVar size_* i.idMUN if e(sample), cluster(IDH_polygon)
			if _rc==0 {
				outreg2 using "TA9 ExitEntry MktAccess.xls", append label excel dec(3) nor2 nocons cttop(Pr(Entry), ${n`g'}) keep(TempInteract RCT_status TempVar) adds("Control mean", `controlmean_local')
			}
			drop TempVar
			drop TempInteract
		}
	}
}

capture erase "TA9 EntryExit MktAccess.xls"